SystemOrganization addCategory: #ConfigurationOfTropo!

Object subclass: #ConfigurationOfTropo
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfTropo'!

!ConfigurationOfTropo class methodsFor: 'private' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfTropo class methodsFor: 'private' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfTropo class methodsFor: 'metacello tool support' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfTropo class methodsFor: 'metacello tool support' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfTropo class methodsFor: 'loading' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfTropo class methodsFor: 'metacello tool support' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfTropo class methodsFor: 'accessing' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
project

	^self new project! !

!ConfigurationOfTropo class methodsFor: 'unloading Metacello' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfTropo methodsFor: 'baselines' stamp: 'PaulDeBruicker 4/11/2011 14:37'!
baseline100: spec
	<version: '1.0-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://www.squeaksource.com/Tropo'.
			spec
				project: 'KomHttpServer'
					with: [ 
							spec
								className: 'ConfigurationOfKomHttpServer';
								repository: 'http://www.squeaksource.com/KomHttpServer' ];
				package: 'JSON' with: [ spec repository: 'http://www.squeaksource.com/JSON' ];
				project: 'ZincHTTPComponents'
					with: [ 
							spec
								className: 'ConfigurationOfZincHTTPComponents';
								repository: 'http://www.squeaksource.com/ZincHTTPComponents' ];
				yourself.
			spec package: 'Tropo' with: [ spec requires: #( 'KomHttpServer' 'JSON' 'ZincHTTPComponents') ].
			spec
				group: 'default' with: #('Core');
				group: 'Core' with: #('Tropo') ]! !

!ConfigurationOfTropo methodsFor: 'accessing' stamp: 'PaulDeBruicker 12/29/2010 19:11'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfTropo methodsFor: 'accessing' stamp: 'PaulDeBruicker 4/11/2011 09:01'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfTropo methodsFor: 'versions' stamp: 'PaulDeBruicker 4/11/2011 14:37'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec
			project: 'KomHttpServer' with: '1.0.8'; 
			project:'ZincHTTPComponents' with:'1.0'.
		spec 
			package: 'JSON' with:'JSON-ul.35';
			package: 'Tropo' with: 'Tropo-PaulDeBruicker.9'].! !
